@@ -25,6 +25,7 @@ import numpy
 
 from .DataHolder import DataHolder
 from .FElement import FElement
+from .Types import NTP
 
 
 class EAttribute(FElement):
@@ -40,7 +41,7 @@ class EAttribute(FElement):
         :param last: the last element from the stack
         :type last: :class:`nxswriter.Element.Element`
         :param streams: tango-like steamset class
-        :type streams: :class:`StreamSet` or :class:`PyTango.Device_4Impl`
+        :type streams: :class:`StreamSet` or :class:`tango.Device_4Impl`
         """
 
         FElement.__init__(self, "attribute", attrs, last, streams=streams)
@@ -67,7 +68,6 @@ class EAttribute(FElement):
         :returns: (strategy,trigger)
         :rtype: (:obj:`str`, :obj:`str`)
         """
-
         if "name" in self._tagAttrs.keys():
             self.name = self._tagAttrs["name"]
             if "type" in self._tagAttrs.keys():
@@ -75,11 +75,18 @@ class EAttribute(FElement):
             else:
                 tp = "NX_CHAR"
 
-            if tp == "NX_CHAR":
-                shape = self._findShape(self.rank, self.lengths)
-            else:
-                shape = self._findShape(self.rank, self.lengths,
-                                        extends=True, checkData=True)
+            try:
+                if tp == "NX_CHAR":
+                    shape = self._findShape(self.rank, self.lengths)
+                else:
+                    shape = self._findShape(self.rank, self.lengths,
+                                            extends=True, checkData=True)
+            except Exception:
+                if self.rank and int(self.rank) >= 0:
+                    shape = [1] * (int(self.rank))
+                else:
+                    shape = [1]
+
             if sys.version_info > (3,):
                 val = ("".join(self.content)).strip()
             else:
@@ -118,7 +125,18 @@ class EAttribute(FElement):
                                 "Attribute::run() - %s " % message[0])
                         self.error = message
                     else:
+                        vl = dh.cast(self.h5Object.dtype)
+                        if hasattr(vl, "shape") and \
+                                hasattr(self.h5Object, "shape") and \
+                                tuple(vl.shape) != tuple(self.h5Object.shape):
+                            self.h5Object = \
+                                self.last.h5Object.attributes.create(
+                                    self.name,
+                                    NTP.nTnp[
+                                        self.last.tagAttributes[self.name][0]],
+                                    vl.shape, overwrite=True)
                         self.h5Object[...] = dh.cast(self.h5Object.dtype)
+
         except Exception:
             message = self.setMessage(sys.exc_info()[1].__str__())
             self.error = message
@@ -156,8 +174,11 @@ class EAttribute(FElement):
                     value = numpy.iinfo(getattr(numpy, nptype)).max
             except Exception:
                 try:
-                    value = numpy.asscalar(
-                        numpy.finfo(getattr(numpy, nptype)).max)
+                    try:
+                        value = numpy.finfo(getattr(numpy, nptype)).max.item()
+                    except Exception:
+                        value = numpy.asscalar(
+                            numpy.finfo(getattr(numpy, nptype)).max)
                 except Exception:
                     value = 0
         else:
