@@ -45,7 +45,7 @@ class EField(FElementWithAttr):
         :param last: the last element from the stack
         :type last: :class:`nxswriter.Element.Element`
         :param streams: tango-like steamset class
-        :type streams: :class:`StreamSet` or :class:`PyTango.Device_4Impl`
+        :type streams: :class:`StreamSet` or :class:`tango.Device_4Impl`
         :param reloadmode: reload mode
         :type reloadmode: :obj:`bool`
         """
@@ -613,8 +613,11 @@ class EField(FElementWithAttr):
                     value = numpy.iinfo(getattr(numpy, nptype)).max
             except Exception:
                 try:
-                    value = numpy.asscalar(
-                        numpy.finfo(getattr(numpy, nptype)).max)
+                    try:
+                        value = numpy.finfo(getattr(numpy, nptype)).max.item()
+                    except Exception:
+                        value = numpy.asscalar(
+                            numpy.finfo(getattr(numpy, nptype)).max)
                 except Exception:
                     value = 0
         else:
