@@ -42,6 +42,7 @@ from .H5Elements import EFile
 from .EGroup import EGroup
 from .DecoderPool import DecoderPool
 from .DataSourcePool import DataSourcePool
+from .Metadata import Metadata, NXSMETA
 
 
 WRITERS = {}
@@ -59,13 +60,16 @@ except Exception:
 DEFAULTWRITERS = ["h5cpp", "h5py"]
 
 
-#: (:obj:`bool`) PyTango bug #213 flag related to EncodedAttributes in python3
+#: (:obj:`bool`) tango bug #213 flag related to EncodedAttributes in python3
 PYTG_BUG_213 = False
 if sys.version_info > (3,):
     try:
-        import PyTango
+        try:
+            import tango
+        except Exception:
+            import PyTango as tango
         PYTGMAJOR, PYTGMINOR, PYTGPATCH = list(
-            map(int, PyTango.__version__.split(".")[:3]))
+            map(int, tango.__version__.split(".")[:3]))
         if PYTGMAJOR <= 9:
             if PYTGMAJOR == 9:
                 if PYTGMINOR < 2:
@@ -88,7 +92,7 @@ class TangoDataWriter(object):
 
         :brief: It initialize the data writer for the H5 output file
         :param server: Tango server
-        :type server: :class:`PyTango.Device_4Impl`
+        :type server: :class:`tango.Device_4Impl`
         """
         #: (:obj:`str`) output file name and optional nexus parent path
         self.__parent = ""
@@ -120,6 +124,9 @@ class TangoDataWriter(object):
         #:  :class:`nxswriter.ThreadPool.ThreadPool` >) \
         #:     collection of thread pool with triggered STEP elements
         self.__triggerPools = {}
+        #: (:obj:`list` <:obj:`dict` <:obj:`str`, :obj:`str` > >) \
+        #: list of entry group attributes
+        self.__entryAttrs = []
         #: (:class:`nxswriter.FileWriter.FTGroup`) H5 file handle
         self.__nxRoot = None
         #: (:obj: `list` <:class:`nxswriter.FileWriter.FTGroup` >)
@@ -139,6 +146,8 @@ class TangoDataWriter(object):
                 self.writer = wr
                 break
 
+        #: (:obj:`str`) metadata output
+        self.metadataOutput = ''
         #: (:obj:`int`) steps per file
         self.stepsperfile = 0
 
@@ -167,7 +176,7 @@ class TangoDataWriter(object):
         #: (:obj:`dict` < :obj:`str`, :obj:`str`>) file time stamps
         self.__filetimes = {}
 
-        #: (:class:`StreamSet` or :class:`PyTango.Device_4Impl`) stream set
+        #: (:class:`StreamSet` or :class:`tango.Device_4Impl`) stream set
         self._streams = StreamSet(weakref.ref(server) if server else None)
 
         #: (:obj:`bool`) skip acquisition flag
@@ -175,7 +184,7 @@ class TangoDataWriter(object):
         if PYTG_BUG_213:
             self._streams.error(
                 "TangoDataWriter::TangoDataWriter() - "
-                "Reading Encoded Attributes for python3 and PyTango < 9.2.5"
+                "Reading Encoded Attributes for python3 and tango < 9.2.5"
                 " is not supported ")
 
     def __setWriter(self, writer):
@@ -493,6 +502,8 @@ class TangoDataWriter(object):
             self.__finalPool = handler.finalPool
             self.__triggerPools = handler.triggerPools
 
+            self.__entryAttrs = handler.entryAttrs
+
             self.__initPool.numberOfThreads = self.numberOfThreads
             self.__stepPool.numberOfThreads = self.numberOfThreads
             self.__finalPool.numberOfThreads = self.numberOfThreads
@@ -674,6 +685,23 @@ class TangoDataWriter(object):
         if self.__nxFile and hasattr(self.__nxFile, "flush"):
             self.__nxFile.flush()
 
+        if NXSMETA and self.__nxRoot:
+            args = {}
+            if self.metadataOutput and \
+               'file' in self.metadataOutput.split(","):
+                for ad in self.__entryAttrs:
+                    nm = ad.get("name", None)
+                    tp = ad.get("type", None)
+                    if nm and tp in ["NXentry"]:
+                        args["output"] = "%s.%s.json" % (
+                            self.__fileName, ad["name"])
+                        args["args"] = [self.__fileName]
+                        args["entrynames"] = nm
+                        mdata = Metadata(self.__nxRoot).get(**args)
+                        if mdata:
+                            if args["output"]:
+                                with open(args["output"], "w") as fl:
+                                    fl.write(mdata)
         gc.collect()
 
     def closeFile(self):
@@ -749,7 +777,8 @@ if __name__ == "__main__":
             xmlf = sys.argv[i]
 
             #: (:obj:`str`) xml string
-            xml = open(xmlf, 'r').read()
+            with open(xmlf, 'r') as fl:
+                xml = fl.read()
             tdw.xmlsettings = xml
 
             print("opening the data entry ")
